<?php

show_admin_bar(false);
require_once('wp_bootstrap_navwalker.php');

if ( ! function_exists( 'ecom_setup' ) ) {

    function ecom_setup() {
        /** Make theme available for translation. */
        load_theme_textdomain( 'ecom', get_template_directory() . '/languages' );

        /** Enable support for Post Thumbnails on posts and pages. */
        add_theme_support( 'post-thumbnails' );

        /** This theme uses wp_nav_menu() in one location. */
        register_nav_menus( array(
          'menu-1' => esc_html__( 'Primary menu', 'ecom' ),
          'menu-2' => esc_html__( 'Footer menu', 'ecom' ),
        ) );

        /** Woocommerce Support */
        add_theme_support( 'woocommerce' );
        //add_theme_support( 'wc-product-gallery-zoom' );
    }
}
add_action( 'after_setup_theme', 'ecom_setup' );


/*** Enqueue scripts and styles. */
function ecom_scripts() {

  /*** Enqueue styles. */
  wp_enqueue_style('adobe-typekit', 'https://use.typekit.net/nix8eqh.css', array(), false, 'all');
  wp_enqueue_style('plugins', get_template_directory_uri() . '/css/plugins.css', array(), date("ymd-Gis", filemtime( get_template_directory() . '/css/plugins.css' )), 'all');
  wp_enqueue_style( 'ecom-style', get_stylesheet_uri(), array(), date("ymd-Gis", filemtime( get_stylesheet_directory())));

  /*** Enqueue scripts. */
  wp_enqueue_script('jquery');
  wp_enqueue_script('plugins', get_template_directory_uri() . '/js/plugins.js', array(), date("ymd-Gis", filemtime( get_template_directory() . '/js/plugins.js' )), true);
  $gmap_api = get_field('google_map_api_key', 'options');
  $googleapi = "https://maps.googleapis.com/maps/api/js?key=$gmap_api";
  wp_enqueue_script('gmap_api', $googleapi, array(), false, true);
  wp_enqueue_script('scripts', get_template_directory_uri() . '/js/scripts.js', array(), date("ymd-Gis", filemtime( get_template_directory() . '/js/scripts.js' )), true);

  $map_icon = get_field('map_pin', 'options');
  $location = get_field('google_map');

  $data = array(
    'gmap_latitude' => $location['lat'],
    'gmap_longitude' => $location['lng'],
    'gmap_address' => $location['address'],
    'map_icon' => $map_icon,
    'site_url' => get_template_directory_uri()
  );
  wp_localize_script('scripts', 'ajax', $data);

}
add_action( 'wp_enqueue_scripts', 'ecom_scripts' );

/*** Register and enqueue a custom stylesheet in the WordPress admin. */
function ecom_scripts_admin() {
    wp_enqueue_style('icon-fonts', get_template_directory_uri() . '/css/icon_fonts.css', array(), false, 'all');
}
add_action( 'admin_enqueue_scripts', 'ecom_scripts_admin' );

/**
 * Dashboard google map api key support.
 */
add_filter('acf/settings/google_api_key', function () {
  $gmap_api = get_field('google_map_api_key', 'options');
    return $gmap_api;
});

/*** ACF OPTIONS PAGE */
if(function_exists('acf_add_options_page')) {
    acf_add_options_page();
}

/*** Reorder dashboard menu */
function reorder_admin_menu( $__return_true ) {
    return array(
         'index.php',                 // Dashboard
         'separator1',                // --Space--
         'acf-options',               // ACF Theme Settings
         'edit.php?post_type=page',   // Pages 
         'edit.php',                  // Posts
         'edit.php?post_type=artist', // artist
         'separator2',                // --Space--
         'gf_edit_forms',             // Gravity Forms
         'upload.php',                // Media
         'wpseo_dashboard',           // Yoasta
         'gadash_settings',           // Google Analytics
         'themes.php',                // Appearance
         'edit-comments.php',         // Comments 
         'users.php',                 // Users
         'tools.php',                 // Tools
         'options-general.php',       // Settings
         'plugins.php',               // Plugins
   );
}
add_filter( 'custom_menu_order', 'reorder_admin_menu' );
add_filter( 'menu_order', 'reorder_admin_menu' );

/*** Remove dashboard menu */
function remove_admin_menus() {
  remove_menu_page( 'edit-comments.php' );              // Comments
  remove_menu_page( 'tools.php' );                      // Tools
  remove_menu_page( 'plugins.php' );                    // Plugings
  remove_menu_page( 'sharethis-general' );          // share this
  remove_menu_page( 'edit.php?post_type=acf-field-group' ); // Custom Field 
  remove_menu_page( 'pods' );                         // Pods Custom post type
}
add_action( 'admin_menu', 'remove_admin_menus', 999);

/*** GC Color Theme */
function additional_admin_color_schemes() {
  //Get the theme directory
  $theme_dir = get_template_directory_uri();

  //GoingClear
  wp_admin_css_color(
    'goingclear', __('GoingClear'),
    admin_url("css/colors/goingclear/colors.css"),
    array('#8ec652', '#008cc6', '#e5e5e5', '#999'),
    array( 'base' => '#e5f8ff', 'focus' => '#fff', 'current' => '#fff' )
  );
}
add_action('admin_init', 'additional_admin_color_schemes');

/*** Reset GC Color Theme as Default for New Users */
function set_default_admin_color($user_id) {
  $args = array(
      'ID' => $user_id,
      'admin_color' => 'goingclear'
    );
    wp_update_user( $args );
}
add_action('user_register', 'set_default_admin_color');

/*** Remove Login Wiggle */
function remove_login_shake() {
    // remove the wp_shake JavaScript
    remove_action( 'login_head', 'wp_shake_js', 12 );
}
add_action( 'login_head', 'remove_login_shake' );

function custom_header() { 
    echo '<link rel="stylesheet" type="text/css" href="' . get_bloginfo('template_directory') . '../../../../wp-admin/admin/login.css" />'; 
    echo '<script type="text/javascript" src="' . get_bloginfo('template_directory') . '../../../../wp-admin/admin/jquery-3.2.1.min.js"></script>';
    echo '<script type="text/javascript" src="' . get_bloginfo('template_directory') . '../../../../wp-admin/admin/login.js"></script>';
   
}
add_action('login_head', 'custom_header');

/*** Gravity form user role */
function gforms_editor_access() {
    $role = get_role( 'editor' );
    $role->add_cap( 'gform_full_access' );
}
add_action( 'after_switch_theme', 'gforms_editor_access' );

/*** Gravity form anchor */
add_filter( 'gform_confirmation_anchor', '__return_false' );

/*** Limit blog text */
function Limit_Text($text, $limit=30){
  $array = explode( "\n", wordwrap( $text, $limit));
  return $array['0'];
}

/*** Change the featured image metabox title text */
function product_featured_image_title() {
    remove_meta_box( 'postimagediv', 'product', 'side' );
    add_meta_box( 'postimagediv', __( 'Product image 250px by 130px', 'ecom' ), 'post_thumbnail_meta_box', 'product', 'side' );
}
add_action('do_meta_boxes', 'product_featured_image_title' );

/**
 * ACF not working use jquery
 *
 */
function hide_editor_custom_js() {
    echo '<script type="text/javascript">
            jQuery(document).ready(function(){
                jQuery("#page_template").change( function() {
                    jQuery("#_home_page_options").hide();
                    jQuery("#postdivrich").show();
                    switch( jQuery( this ).val() ) {
                        case "t_home.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_about.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_contact.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_privacy_policy.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_cart.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_checkout.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;

                        case "t_my_account.php":
                          jQuery("#_home_page_options").show();
                          jQuery("#postdivrich").hide();
                        break;
                    }
                }).change();
            });
        </script>';
}
add_action('admin_head', 'hide_editor_custom_js');


/***********************************
* Woocommerce 
************************************/

/** Woocommerce Remove Action */
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );

// /** Woocommerce Add Action */

/* top sorting bar */
add_action('woocommerce_before_shop_loop', 'warp_before_filter_items', 10);
add_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 11 );
add_action( 'woocommerce_before_shop_loop', 'result_pagination_wrapper', 12 );
add_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 13 );
add_action( 'woocommerce_before_shop_loop', 'woocommerce_pagination', 14 );
add_action('woocommerce_before_shop_loop', 'end_warp_before_filter_items', 15);


/* bottom sorting bar */
add_action('woocommerce_after_shop_loop', 'warp_before_filter_items', 10);
add_action( 'woocommerce_after_shop_loop', 'woocommerce_catalog_ordering', 11 );
add_action( 'woocommerce_after_shop_loop', 'result_pagination_wrapper', 12 );
add_action( 'woocommerce_after_shop_loop', 'woocommerce_result_count', 13 );
add_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 14 );
add_action('woocommerce_after_shop_loop', 'end_warp_before_filter_items', 15);

/** Remove the product rating display on product loops */ 
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

/** Woocommerce Shop After product filter wrapper class add */
function result_pagination_wrapper(){
  echo '<div class="pagination_result_count">';
}

function warp_before_filter_items() {
  echo '<div class="wrap_filter_items">';
}

function end_warp_before_filter_items() {
  echo '</div></div>';
}

/** Shop page how many products show */
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 9;' ), 20 );

/** Ecom related products count */
function related_products_count( $args ) {
     $args['posts_per_page'] = 3;
     $args['columns'] = 3;
 
     return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'related_products_count' );

/** Woocommerce Breadcrumb*/ 
function ecom_remove_wc_breadcrumbs() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}
add_action( 'init', 'ecom_remove_wc_breadcrumbs' );

/** Woocommerce Breadcrumb delimiter change */ 
function ecom_change_breadcrumb_delimiter( $defaults ) {
  $defaults['delimiter'] = '<span class="icon-arrow-right"></span>';
  return $defaults;
}
add_filter('woocommerce_breadcrumb_defaults', 'ecom_change_breadcrumb_delimiter');

/** Header right mini cart number ajaxify */
function ecom_header_ajaxify_add_to_cart( $fragments ) {
  global $woocommerce;
  
  ob_start();
  
  ?>
  <a class="ajaxify_cart" href="<?php echo $woocommerce->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'ecom'); ?>">
      <div class="mini_cart">
          <i class="icon-cart"></i>
        <span class="cart_quantity"><?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'ecom'), $woocommerce->cart->cart_contents_count);?></span>
      </div>
  </a>
  <?php
  
  $fragments['.ajaxify_cart'] = ob_get_clean();
  
  return $fragments;
  
}
add_filter('add_to_cart_fragments', 'ecom_header_ajaxify_add_to_cart');

/** Header right mini cart hover load cart item ajaxify * Js Part settings.js File */
function mode_theme_update_mini_cart() {
    echo wc_get_template( 'cart/mini-cart.php' );
    die();
}
add_filter( 'wp_ajax_nopriv_mode_theme_update_mini_cart', 'mode_theme_update_mini_cart' );
add_filter( 'wp_ajax_mode_theme_update_mini_cart', 'mode_theme_update_mini_cart' );

/** Change checkout form field placeholder and label */  
function ecom_checkout_fields_placeholder( $fields ) {
    // Label remove
    $fields['billing']['billing_first_name']['label'] = '';
    $fields['billing']['billing_last_name']['label'] = '';
    $fields['billing']['billing_company']['label'] = '';
    $fields['billing']['billing_email']['label'] = '';
    $fields['billing']['billing_phone']['label'] = '';
    $fields['billing']['billing_postcode']['label'] = '';
    $fields['billing']['billing_country']['label'] = '';
    $fields['billing']['billing_address_1']['label'] = '';

    // Placeholder add 
    $fields['billing']['billing_first_name']['placeholder'] = 'First Name *';
    $fields['billing']['billing_last_name']['placeholder'] = 'Last Name *';
    $fields['billing']['billing_company']['placeholder'] = 'Company Name';
    $fields['billing']['billing_email']['placeholder'] = 'Email Address *';
    $fields['billing']['billing_phone']['placeholder'] = 'Phone *';
    $fields['billing']['billing_postcode'] = array(
        'placeholder' => _x('Postcode *', 'placeholder', 'woocommerce'),
    );
    $fields['billing']['billing_address_1'] = array(
        'type' => 'textarea',
        'placeholder' => _x('Address *', 'placeholder', 'woocommerce'),
    );

    // Add field priority
    $fields['billing']['billing_email']['priority'] = 30;
    $fields['billing']['billing_phone']['priority'] = 40;
    $fields['billing']['billing_country']['priority'] = 50;
    $fields['billing']['billing_postcode']['priority'] = 60;
    $fields['billing']['billing_address_1']['priority'] = 90;

    //$fields['billing']['billing_state']['label'] = '';
    return $fields;
}
add_filter( 'woocommerce_checkout_fields' , 'ecom_checkout_fields_placeholder', 10, 1);

/** remove checkout form field in Woocommerce */  
function after_woocommerce_checkout_fields( $fields ) {
     unset($fields['billing']['billing_address_2']);
     unset($fields['billing']['billing_city']);
     unset($fields['billing']['billing_state']);
     unset($fields['order']['order_comments']);
     return $fields;
}
add_filter( 'woocommerce_checkout_fields' , 'after_woocommerce_checkout_fields' );

/** Checkout Page Payment Method heading Add */
function payment_method_heading() {
    echo '<h3 id="payment_method_heading">Payment Method</h3>';
}
add_action( 'woocommerce_review_order_before_payment', 'payment_method_heading' );

/** Custom icon for PayPal payment option on WooCommerce checkout page. */
function ecom_extended_paypal_icon() {
    return get_stylesheet_directory_uri() . '/images/payment_method_paypal.png';
}
add_filter( 'woocommerce_paypal_icon', 'ecom_extended_paypal_icon' );

function change_shipping_text($sprintf, $i, $package){
    return 'Shipping & Handling';
}

add_filter('woocommerce_shipping_package_name', 'change_shipping_text', 10, 3);

/* single product */
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);



add_action('woocommerce_before_add_to_cart_button', 'is_in_stock_and_quantity_field');
add_action('woocommerce_before_add_to_cart_button', 'woocommerce_template_single_excerpt', 12);

// add_action('woocommerce_single_product_summary', 'is_in_stock_and_quantity_field', 11);
function is_in_stock_and_quantity_field(){
    ob_start();
    global $product;
    ?>
    <div class="row align-center-v">
        <div class="col-md-6 col-sm-6 col-xs-6 col">
            <div class="available_in_stock text-uppercase"><label>Available:</label><?php $product->is_in_stock() ? _e(' In Stock', 'woocommerce') : _e(' Out of Stock', 'woocommerce');
            ?></div>
        </div>
        <div class="col-md-6 col-sm-6 col-xs-6 col">
            <?php 
                woocommerce_quantity_input( array(
                 'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
                 'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
                 'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( $_POST['quantity'] ) : $product->get_min_purchase_quantity(),
                ) );
        ?>
        </div>
    </div>

    <?php 
    $html = ob_get_contents();
    ob_get_clean();
    echo $html;
}


/* color filter widget modify */
add_filter('woocommerce_layered_nav_count', 'colors_filter_widget', 10, 3);

function colors_filter_widget($span, $count, $term){
    return '<span class="color" style="color:'. esc_html( strtolower( $term->name ) ) .'"></span>' . $span;
}